import qualified MegaModule as M
  ( -- (1)
    -- (2)
    Either, -- (3)
    (<<<),
    (>>>),
  )
